@@ -12,17 +12,17 @@
 
 #define QT_FEATURE_videotoolbox -1
 
-#define QT_FEATURE_gstreamer 1
+#define QT_FEATURE_gstreamer -1
 
-#define QT_FEATURE_gstreamer_photography 1
+#define QT_FEATURE_gstreamer_photography -1
 
-#define QT_FEATURE_gstreamer_gl 1
+#define QT_FEATURE_gstreamer_gl -1
 
 #define QT_FEATURE_gstreamer_gl_wayland -1
 
-#define QT_FEATURE_gstreamer_gl_egl 1
+#define QT_FEATURE_gstreamer_gl_egl -1
 
-#define QT_FEATURE_gstreamer_gl_x11 1
+#define QT_FEATURE_gstreamer_gl_x11 -1
 
 #define QT_FEATURE_gpu_vivante -1
 
@@ -30,7 +30,7 @@
 
 #define QT_FEATURE_linux_dmabuf 1
 
-#define QT_FEATURE_vaapi -1
+#define QT_FEATURE_vaapi 1
 
 #define QT_FEATURE_mmrenderer -1
 
@@ -38,8 +38,6 @@
 
 #define QT_FEATURE_pulseaudio -1
 
-#define QT_FEATURE_wmsdk -1
-
 #define QT_FEATURE_opensles -1
 
 #define QT_FEATURE_wasm -1
@@ -50,3 +48,5 @@
 
 #define QT_FEATURE_spatialaudio_quick3d 1
 
+#define QT_FEATURE_ffmpeg_stubs -1
+
